@@ -1,5 +1,6 @@
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
+from django.http import HttpRequest, HttpResponse
 from django.shortcuts import redirect, render
 from dynamic_preferences.users.forms import user_preference_form_builder
 
@@ -22,3 +23,8 @@ def index(request):
             PreferencesForm = user_preference_form_builder(instance=request.user.user)
 
     return render(request, 'magplan/preferences/index.html', {'form': PreferencesForm})
+
+
+@login_required
+def set_current_site(request: HttpRequest) -> HttpResponse:
+    ...
